@@ -568,7 +568,7 @@ fill_time_digits ()
   tm = localtime (&clock);
   clock++;
 #else
-  long clock = time ((time_t *) 0);
+  time_t clock = time ((time_t *) 0);
   struct tm *tm = localtime (&clock);
 #endif
   if (test_hack)
@@ -1270,7 +1270,7 @@ run_digital (dpy, window)
 	   or by select()ing on the display file descriptor, but that
 	   would be more work.
 	 */
-	long now = time ((time_t *) 0);
+	time_t now = time ((time_t *) 0);
 	struct tm *tm = localtime (&now);
 	long target = now + (60 - tm->tm_sec);
 	while ((now = time ((time_t *) 0)) <= target)
