@@ -1,5 +1,6 @@
 /* xdaliclock - a melting digital clock
- * Copyright (c) 1991, 1992, 1993, 1994, 1995 Jamie Zawinski <jwz@netscape.com>
+ * Copyright (c) 1991, 1992, 1993, 1994, 1995, 1996
+ *  Jamie Zawinski <jwz@netscape.com>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -91,6 +92,12 @@ main (argc, argv)
   XWindowAttributes xgwa;
   Bool full_screen_p;
 
+#if (XtSpecificationRelease >= 4)
+  int argc_copy = argc;
+  char **argv_copy = (char **) malloc (argc * sizeof(*argv));
+  memcpy(argv_copy, argv, argc * sizeof(*argv));
+#endif
+
   hack_version ();
   progclass = "XDaliClock";
 
@@ -254,6 +261,15 @@ main (argc, argv)
       window = XtWindow (toplevel);
     }
 
+#if (XtSpecificationRelease >= 4)
+  if (!root_p)
+    XSetStandardProperties(dpy, window, progname, progname,
+			   NULL, /* icon pixmap */
+			   argv_copy, argc_copy,
+			   NULL /* XSizeHints* */);
+  free(argv_copy);
+#endif
+
   run_digital (dpy, window);
   return (0);
 }
